==> rdc_flutter_sdk-0.0.1.tar.gz: lib/src/model/rabbit_request.dart <==
import 'dart:convert';
import 'base_model.dart';
import 'hive/rabbit_request_hive.dart';
import 'realm/rabbit_request_realm.dart';

class RabbitRequest
    implements BaseModel<RabbitRequestHive, RabbitRequestRealm> {
  RabbitRequest(
      {this.id = 0,
      this.memberId = '',
      this.ssoId = '',
      this.globalId = '',
      this.sdkVersion = '',
      this.sessionEvent = '',
      this.sessionId = '',
      this.touchPoint = 'mobile_app',
      this.eventName = '',
      this.eventValue = '',
      this.osVer = '',
      this.osType = '',
      this.display = '',
      this.localeCountry = '',
      this.localeLang = '',
      this.latitude = '',
      this.longitude = '',
      this.maid = '',
      this.device = '',
      this.model = '',
      this.brandName = '',
      this.board = '',
      this.appVer = '',
      this.appVerNum = '',
      this.prevAppVer = '',
      this.prevAppVerNum = '',
      this.dataLayer,
      this.time = '',
      this.isSend = false});

  @override
  int id;
  String memberId;
  String ssoId;
  String globalId;
  String sdkVersion;
  String sessionEvent;
  String sessionId;
  String touchPoint;
  String eventName;
  String eventValue;
  String osVer;
  String osType;
  String display;
  String localeCountry;
  String localeLang;
  String latitude;
  String longitude;
  String maid;
  String device;
  String model;
  String brandName;
  String board;
  String appVer;
  String appVerNum;
  String prevAppVer;
  String prevAppVerNum;
  Map? dataLayer;
  String time;
  bool isSend;

  factory RabbitRequest.fromRawJson(String str) =>
      RabbitRequest.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory RabbitRequest.fromJson(Map<String, dynamic> json) => RabbitRequest(
        memberId: json["member_id"],
        ssoId: json["sso_id"],
        globalId: json["global_id"],
        sdkVersion: json["sdk_version"],
        sessionEvent: json["session_event"],
        sessionId: json["session_id"],
        touchPoint: json["touch_point"],
        eventName: json["event_name"],
        eventValue: json["event_value"],
        osVer: json["os_ver"],
        osType: json["os_type"],
        display: json["display"],
        localeCountry: json["locale_country"],
        localeLang: json["locale_lang"],
        latitude: json["latitude"],
        longitude: json["longitude"],
        maid: json["maid"],
        device: json["device"],
        model: json["model"],
        brandName: json["brand_name"],
        board: json["board"],
        appVer: json["app_ver"],
        appVerNum: json["app_ver_num"],
        prevAppVer: json["prev_app_ver"],
        prevAppVerNum: json["prev_app_ver_num"],
        dataLayer: json["data_layer"],
        time: json["time"],
        isSend: json["is_send"],
      );

  Map<String, dynamic> toJson() => {
        "member_id": memberId,
        "sso_id": ssoId,
        "global_id": globalId,
        "sdk_version": sdkVersion,
        "session_event": sessionEvent,
        "session_id": sessionId,
        "touch_point": touchPoint,
        "event_name": eventName,
        "event_value": eventValue,
        "os_ver": osVer,
        "os_type": osType,
        "display": display,
        "locale_country": localeCountry,
        "locale_lang": localeLang,
        "latitude": latitude,
        "longitude": longitude,
        "maid": maid,
        "device": device,
        "model": model,
        "brand_name": brandName,
        "board": board,
        "app_ver": appVer,
        "app_ver_num": appVerNum,
        "prev_app_ver": prevAppVer,
        "prev_app_ver_num": prevAppVerNum,
        "data_layer": dataLayer,
        "time": time,
        "is_send": isSend
      };

  @override
  RabbitRequestHive mapToHive() {
    return RabbitRequestHive()
      ..memberId = memberId
      ..ssoId = ssoId
      ..globalId = globalId
      ..sdkVersion = sdkVersion
      ..touchPoint = touchPoint
      ..sessionEvent = sessionEvent
      ..sessionId = sessionId
      ..eventName = eventName
      ..eventValue = eventValue
      ..osVer = osVer
      ..osType = osType
      ..display = display
      ..localeCountry = localeCountry
      ..localeLang = localeLang
      ..latitude = latitude
      ..longitude = longitude
      ..maid = maid
      ..device = device
      ..model = model
      ..brandName = brandName
      ..board = board
      ..appVer = appVer
      ..appVerNum = appVerNum
      ..prevAppVer = prevAppVer
      ..prevAppVerNum = prevAppVerNum
      ..dataLayer = dataLayer
      ..time = time
      ..isSend = isSend;
  }

  @override
  RabbitRequestRealm mapToRealm() {
    return RabbitRequestRealm(
      id,
      memberId,
      ssoId,
      globalId,
      sdkVersion,
      touchPoint,
      sessionEvent,
      sessionId,
      eventName,
      eventValue,
      osVer,
      osType,
      display,
      localeCountry,
      localeLang,
      latitude,
      longitude,
      maid,
      device,
      model,
      brandName,
      board,
      appVer,
      appVerNum,
      prevAppVer,
      prevAppVerNum,
      time,
      dataLayer: json.encode(dataLayer),
      isSend: isSend,
    );
  }

  static String boxName = 'rabbit_request';
}

==> rdc_flutter_sdk-0.0.17.tar.gz: lib/src/model/rabbit_request.dart <==
import 'dart:convert';
import 'base_model.dart';
import 'hive/rabbit_request_hive.dart';
import 'realm/rabbit_request_realm.dart';
import '../constants/app_constants.dart' as con;

class RabbitRequest
    implements BaseModel<RabbitRequestHive, RabbitRequestRealm> {
  RabbitRequest(
      {this.id = 0,
      this.memberId = '',
      this.ssoId = '',
      this.globalId = '',
      this.sdkVersion = '',
      this.sessionEvent = '',
      this.sessionId = '',
      this.touchPoint = con.touchPoint,
      this.eventName = '',
      this.eventValue = '',
      this.osVer = '',
      this.osType = '',
      this.display = '',
      this.localeCountry = '',
      this.localeLang = '',
      this.latitude,
      this.longitude,
      this.maid,
      this.device = '',
      this.model = '',
      this.brandName = '',
      this.board = '',
      this.appVer = '',
      this.appVerNum = '',
      this.prevAppVer,
      this.prevAppVerNum,
      this.dataLayer,
      this.time = '',
      this.isSend = false});

  @override
  int id;
  String memberId;
  String ssoId;
  String globalId;
  String sdkVersion;
  String sessionEvent;
  String sessionId;
  String touchPoint;
  String eventName;
  String eventValue;
  String osVer;
  String osType;
  String display;
  String localeCountry;
  String localeLang;
  String? latitude;
  String? longitude;
  String? maid;
  String device;
  String model;
  String brandName;
  String board;
  String appVer;
  String appVerNum;
  String? prevAppVer;
  String? prevAppVerNum;
  Map? dataLayer;
  String time;
  bool isSend;

  factory RabbitRequest.fromRawJson(String str) =>
      RabbitRequest.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory RabbitRequest.fromJson(Map<String, dynamic> json) => RabbitRequest(
      memberId: json["member_id"],
      ssoId: json["sso_id"],
      globalId: json["global_id"],
      sdkVersion: json["sdk_version"],
      sessionEvent: json["session_event"],
      sessionId: json["session_id"],
      touchPoint: json["touch_point"],
      eventName: json["event_name"],
      eventValue: json["event_value"],
      osVer: json["os_ver"],
      osType: json["os_type"],
      display: json["display"],
      localeCountry: json["locale_country"],
      localeLang: json["locale_lang"],
      latitude: json["latitude"],
      longitude: json["longtitude"],
      maid: json["maid"],
      device: json["device"],
      model: json["model"],
      brandName: json["brand_name"],
      board: json["board"],
      appVer: json["app_ver"],
      appVerNum: json["app_ver_num"],
      prevAppVer: json["prev_app_ver"],
      prevAppVerNum: json["prev_app_ver_num"],
      dataLayer: json["data_layer"],
      time: json["time"]);

  Map<String, dynamic> toJson() => {
        "member_id": memberId,
        "sso_id": ssoId,
        "global_id": globalId,
        "sdk_version": sdkVersion,
        "session_event": sessionEvent,
        "session_id": sessionId,
        "touch_point": touchPoint,
        "event_name": eventName,
        "event_value": eventValue,
        "os_ver": osVer,
        "os_type": osType,
        "display": display,
        "locale_country": localeCountry,
        "locale_lang": localeLang,
        "latitude": latitude,
        "longitude": longitude,
        "maid": maid,
        "device": device,
        "model": model,
        "brand_name": brandName,
        "board": board,
        "app_ver": appVer,
        "app_ver_num": appVerNum,
        "prev_app_ver": prevAppVer,
        "prev_app_ver_num": prevAppVerNum,
        "data_layer": dataLayer,
        "time": time
      };

  @override
  RabbitRequestHive mapToHive() {
    return RabbitRequestHive()
      ..memberId = memberId
      ..ssoId = ssoId
      ..globalId = globalId
      ..sdkVersion = sdkVersion
      ..touchPoint = touchPoint
      ..sessionEvent = sessionEvent
      ..sessionId = sessionId
      ..eventName = eventName
      ..eventValue = eventValue
      ..osVer = osVer
      ..osType = osType
      ..display = display
      ..localeCountry = localeCountry
      ..localeLang = localeLang
      ..latitude = latitude ?? ''
      ..longitude = longitude ?? ''
      ..maid = maid ?? ''
      ..device = device
      ..model = model
      ..brandName = brandName
      ..board = board
      ..appVer = appVer
      ..appVerNum = appVerNum
      ..prevAppVer = prevAppVer ?? ''
      ..prevAppVerNum = prevAppVerNum ?? ''
      ..dataLayer = dataLayer
      ..time = time
      ..isSend = isSend;
  }

  @override
  RabbitRequestRealm mapToRealm() {
    return RabbitRequestRealm(
      id,
      memberId,
      ssoId,
      globalId,
      sdkVersion,
      touchPoint,
      sessionEvent,
      sessionId,
      eventName,
      eventValue,
      osVer,
      osType,
      display,
      localeCountry,
      localeLang,
      latitude ?? '',
      longitude ?? '',
      maid ?? '',
      device,
      model,
      brandName,
      board,
      appVer,
      appVerNum,
      prevAppVer ?? '',
      prevAppVerNum ?? '',
      time,
      dataLayer: json.encode(dataLayer),
      isSend: isSend,
    );
  }

  static String boxName = con.rabbitRquestBoxName;
}
